==> mono_1.1.12.1.orig.tar.gz: mono-1.1.12.1/mcs/class/System.Configuration/System.Configuration/ConfigurationCollectionAttribute.cs <==
//
// System.Configuration.ConfigurationCollectionAttribute.cs
//
// Authors:
//  Lluis Sanchez Gual (lluis@novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
// Copyright (C) 2005 Novell, Inc (http://www.novell.com)
//

#if NET_2_0
using System.Collections;

namespace System.Configuration
{
	[AttributeUsage (AttributeTargets.Class | AttributeTargets.Property)]
	public sealed class ConfigurationCollectionAttribute: Attribute
	{
		string addItemName = "add";
		string clearItemsName = "clear";
		string removeItemName = "remove";
		ConfigurationElementCollectionType collectionType = ConfigurationElementCollectionType.BasicMap;
		Type itemType;
		
		public ConfigurationCollectionAttribute (Type itemType)
		{
			this.itemType = itemType;
		}
		
		public string AddItemName {
			get { return addItemName; }
			set { addItemName = value; }
		}
		
		public string ClearItemsName {
			get { return clearItemsName; }
			set { clearItemsName = value; }
		}
		
		public string RemoveItemName {
			get { return removeItemName; }
			set { removeItemName = value; }
		}

		public ConfigurationElementCollectionType CollectionType {
			get { return collectionType; }
			set { collectionType = value; }
		}
		
		[MonoTODO ("Do something with this in ConfigurationElementCollection")]
		public Type ItemType {
			get { return itemType; }
		}
	}
}

#endif

==> mono_2.6.7.orig.tar.gz: mono-2.6.7/mcs/class/System.Configuration/System.Configuration/ConfigurationCollectionAttribute.cs <==
//
// System.Configuration.ConfigurationCollectionAttribute.cs
//
// Authors:
//  Lluis Sanchez Gual (lluis@novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
// Copyright (C) 2005 Novell, Inc (http://www.novell.com)
//

#if NET_2_0
using System.Collections;

namespace System.Configuration
{
	[AttributeUsage (AttributeTargets.Class | AttributeTargets.Property)]
	public sealed class ConfigurationCollectionAttribute: Attribute
	{
		string addItemName = "add";
		string clearItemsName = "clear";
		string removeItemName = "remove";
		ConfigurationElementCollectionType collectionType = ConfigurationElementCollectionType.BasicMap;
		Type itemType;
		
		public ConfigurationCollectionAttribute (Type itemType)
		{
			this.itemType = itemType;
		}
		
		public string AddItemName {
			get { return addItemName; }
			set { addItemName = value; }
		}
		
		public string ClearItemsName {
			get { return clearItemsName; }
			set { clearItemsName = value; }
		}
		
		public string RemoveItemName {
			get { return removeItemName; }
			set { removeItemName = value; }
		}

		public ConfigurationElementCollectionType CollectionType {
			get { return collectionType; }
			set { collectionType = value; }
		}
		
		[MonoInternalNote ("Do something with this in ConfigurationElementCollection")]
		public Type ItemType {
			get { return itemType; }
		}
	}
}

#endif
